﻿using System;
using System.Diagnostics;
using System.IO;
using System.Text;
using System.Windows.Forms;
using System.Xml;

namespace CustomGui
{
    public partial class FrmGui : Form
    {
        public string _ConfigXmlFile;
        public XmlDocument _ConfigXml;

        public FrmGui()
        {
            InitializeComponent();
        }

        private void cmdCancel_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void RemoveConfigurationFile()
        {
            // Removing the configuration XML file will signal that the process should abort.
#if DEBUG
            Debug.WriteLine("Debug mode will not delete input file.");
#else
            File.Delete(_ConfigXmlFile);
#endif
        }

        private void cmdOk_Click(object sender, EventArgs e)
        {
            // Set watermark text
            _ConfigXml.SelectSingleNode("//watermarktext").InnerText = "Custom GUI " + DateTime.Now.ToString("t");

            // Set watermark color
            string color = "";
            if (rbBlue.Checked)
                color = "0000FF";
            else if (rbGreen.Checked)
                color = "00FF00";
            else if (rbRed.Checked)
                color = "FF0000";
            _ConfigXml.SelectSingleNode("//watermarkcolor").InnerText = color;

            // Disable normal dialogs
            _ConfigXml.SelectSingleNode("//showprogress").InnerText = "no";
            _ConfigXml.SelectSingleNode("//showprogressfinished").InnerText = "no";
            _ConfigXml.SelectSingleNode("//showsettings").InnerText = "never";
            _ConfigXml.SelectSingleNode("//showsaveas").InnerText = "never";

            // Show PDF after creation
            _ConfigXml.SelectSingleNode("//showpdf").InnerText = "yes";

            // Set zoom
            _ConfigXml.SelectSingleNode("//zoom").InnerText = "fitall";

            // Set output to temporary files folder
            _ConfigXml.SelectSingleNode("//output").InnerText = "<env:TEMP>\\custom-gui-test-" + Guid.NewGuid().ToString() + ".pdf";

            // Do not use last used values
            _ConfigXml.SelectSingleNode("//rememberlastfilename").InnerText = "no";
            _ConfigXml.SelectSingleNode("//rememberlastfoldername").InnerText = "no";

            // Save new configuration
            _ConfigXml.Save(_ConfigXmlFile);

            Close();
        }

        private void FrmGui_Load(object sender, EventArgs e)
        {
            try
            {
                string[] args = Environment.GetCommandLineArgs();
                if (args.Length != 2)
                    throw new Exception("You must specify the file name of the configuration XML as the command line parameter when running this program.");
                
                _ConfigXmlFile = Path.GetFullPath(args[1]);
                _ConfigXml = new XmlDocument();
                _ConfigXml.Load(_ConfigXmlFile);
                RemoveConfigurationFile();
                txtXml.Text = Beautify(_ConfigXml);

                // Preselct the red option
                rbRed.Select();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Custom GUI Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                Close();
            }
        }

        /// <summary>
        /// Convert an XML document to a string with indentation
        /// </summary>
        /// <param name="doc">Input document</param>
        /// <returns>A text representation of the XML document.</returns>
        static public string Beautify(XmlDocument doc)
        {
            StringBuilder sb = new StringBuilder();
            XmlWriterSettings settings = new XmlWriterSettings();
            settings.Indent = true;
            settings.IndentChars = "  ";
            settings.NewLineChars = "\r\n";
            settings.NewLineHandling = NewLineHandling.Replace;
            using (XmlWriter writer = XmlWriter.Create(sb, settings))
            {
                doc.Save(writer);
            }
            return sb.ToString();
        }

    }
}
